# lume 🔥  

[![version](https://img.shields.io/github/release/alice-biometrics/lume/all.svg)](https://github.com/alice-biometrics/lume/releases) 
[![ci](https://github.com/alice-biometrics/lume/workflows/ci/badge.svg)](https://github.com/alice-biometrics/lume/actions)
[![pypi](https://img.shields.io/pypi/dm/lume)](https://pypi.org/project/lume/) 
[![codecov](https://codecov.io/gh/alice-biometrics/lume/branch/main/graph/badge.svg?token=AS78XD634W)](https://codecov.io/gh/alice-biometrics/lume)
[![license](https://img.shields.io/github/license/alice-biometrics/lume.svg)](https://github.com/alice-biometrics/lume/blob/main/LICENSE)
[![versions](https://img.shields.io/pypi/pyversions/lume.svg)](https://github.com/alice-biometrics/lume)

<img src="https://github.com/alice-biometrics/custom-emojis/blob/master/images/alice_header.png?raw=true" width=auto>

---

**Documentation**: <a href="https://alice-biometrics.github.io/lume/" target="_blank">https://alice-biometrics.github.io/lume/</a>

**Source Code**: <a href="https://github.com/alice-biometrics/lume" target="_blank">https://github.com/alice-biometrics/lume</a>

---

## What is lume?

A handy Python-based automation tool. It can be thought of as a vitaminized `Makefile`. 

## How could lume help me?

`lume` helps you sort your commands, allows you to abstract from the development environment and facilitates CI and CD workflows.
Use the `lume.yml` to define all your daily project commands. 

## Installation 💻

``` bash
pip install lume
```

## Contribute 

We'd love you to contribute to *lume* 🥳🥳🥳🥳🥳🥳️️!

For more information, check our [documentation](https://alice-biometrics.github.io/lume/contributing/)

## Acknowledgements 🙌

`bowie` inspired us! 👨‍🎤 👏👏👏👏👏

We started with the idea of creating a tool to standardize all the commands of the different projects years ago, when most of the `lume` maintenance team was working in the Galician research center, [Gradiant](https://github.com/Gradiant). 
There, we developed the wonderful `bowie` package.
We know that this package is still active in several internal projects of the research center, so long live `bowie` and thanks to the Gradiant team for the initial impulse.

## Contact 📬

support@alicebiometrics.com
